Player

Struct Player 

pub struct Player {
Show 24 fields pub id: String, pub name: String, pub surname: String, pub bio: String, pub pronouns: String, pub alias: String, pub niu: String, pub email: String, pub phone: String, pub faculty: String, pub isuab: bool, pub how_did_you_hear_about_us: String, pub social_media: Option<String>, pub password: String, pub player_number: i32, pub state: PlayerState, pub role: PlayerRole, pub birth_date: NaiveDate, pub accept_info_other_editions: bool, pub next_feeding: Option<CustomDateTime>, pub last_login: Option<NaiveDateTime>, pub checkpoint: Option<NaiveDateTime>, pub wants_to_be_zombie: i32, pub register_date: Option<NaiveDateTime>,
}
Player struct

This is the main struct of the application.

It contains all the information about a player.

Fields

id: Stringname: Stringsurname: Stringbio: Stringpronouns: Stringalias: Stringniu: Stringemail: Stringphone: Stringfaculty: Stringisuab: boolhow_did_you_hear_about_us: Stringsocial_media: Option<String>password: Stringplayer_number: i32state: PlayerStaterole: PlayerRolebirth_date: NaiveDateaccept_info_other_editions: boolnext_feeding: Option<CustomDateTime>last_login: Option<NaiveDateTime>checkpoint: Option<NaiveDateTime>wants_to_be_zombie: i32register_date: Option<NaiveDateTime>

Implementations

Source

impl Player

pub async fn recover_password( &self, username: String, password: String, ) -> Result<(), String>

Allows an admin to recover a player’s password.

Arguments
  • username - The username of the player to recover the password for.
  • password - The new password to set for the player.
Returns
  • Ok(()) if the password was successfully recovered.
  • Err(String) if an error occurred.
pub async fn count_player(&self) -> Result<String, String>

Returns the number of players of each possible player state.

Returns
  • Ok(String) if the count was successfully retrieved.
  • Err(String) if an error occurred.
pub async fn admin_get_players(&self) -> Result<Vec<Player>, String>

Get all players for admins

Returns
  • Ok(Vec<Player>) if the players were successfully retrieved.
  • Err(String) if an error occurred.
pub async fn feed_players(&self, n: i32) -> Result<String, String>

Feeds a certain amount of players

Arguments
  • n - The amount of players to feed.
Returns
  • Ok(String) if the players were successfully fed.
  • Err(String) if an error occurred.
pub async fn admin_feed(&self, id: String) -> Result<String, String>

Feeds a single player.

Arguments
  • id - The ID of the player to feed.
Returns
  • Ok(String) if the player was successfully fed.
  • Err(String) if an error occurred.
pub async fn feed_zombies_day(&self) -> Result<String, String>

Adds a day to the zombies’ feeding time.

Returns
  • Ok(String) if the zombies were successfully fed.
  • Err(String) if an error occurred.
pub async fn cure(&self, id: String) -> Result<String, String>

Cures a player.

Arguments
  • id - The ID of the player to cure.
Returns
  • Ok(String) if the player was successfully cured.
  • Err(String) if an error occurred.
pub async fn transform( &self, alias: String, state: PlayerState, ) -> Result<String, String>

Transforms a player into a certain state.

Arguments
  • alias - The alias of the player to transform.
  • state - The state to transform the player into.
Returns
  • Ok(String) if the player was successfully transformed.
  • Err(String) if an error occurred.
pub async fn set_checkpoint( &self, x: String, y: String, ) -> Result<String, String>

Sets the checkpoint coordinates.

Arguments
  • coordinates - The coordinates to set as the checkpoint.
Returns
  • Ok(String) if the checkpoint was successfully set.
  • Err(String) if an error occurred.
pub async fn player_at_checkpoint( &self, player_id: String, ) -> Result<String, String>

Sets a player passing through the checkpoint

Arguments
  • player_id (player that is at checkpoint)
Returns
  • Ok(String) if the player was registered at the checkpoint successfully.
  • Err(String) if an error occurred.
pub async fn kill_all_not_at_checkpoint(&self) -> Result<String, String>

Kills all players did not go through the checkpoint.

Returns
  • Ok(String) if the players were killed successfully.
  • Err(String) if an error occurred.
pub async fn inject_sql(&self, sql_command: String) -> Result<String, String>

Allows an admin to inject SQL commands.

Arguments
  • sql_command - The SQL command to execute.
Returns
  • Ok(String) if the SQL command was successfully executed.
  • Err(String) if an error occurred.
pub async fn get_logs(&self) -> Result<String, String>

Retrieves the logs from the application.

Returns
  • Ok(String) if the logs were successfully retrieved.
  • Err(String) if an error occurred.
Source

impl Player

Implement Player struct

pub async fn new( name: String, surname: String, pronouns: String, alias: String, niu: String, email: String, phone: String, faculty: String, isuab: bool, how_did_you_hear_about_us: String, social_media: Option<String>, password: String, birth_date: NaiveDate, accept_info_other_editions: bool, wants_to_be_zombie: i32, ) -> Self

Create a new player

Arguments
  • name - The player’s name
  • surname - The player’s surname
  • pronouns - The player’s pronouns
  • alias - The player’s alias
  • niu - The player’s NIU
  • email - The player’s email
  • social_media - The player’s social media
  • phone - The player’s phone number
  • faculty - The player’s faculty
  • isuab - Whether the player is from UAB or not
  • how_did_you_hear_about_us - How the player heard about us
  • password - The player’s password
  • birth_date - The player’s birth date
Returns

A new player instance

fn get_next_player_number() -> i32

Get the next player number

This is used to assign a unique number to each player.

Returns

The next player number

pub async fn signup(&self) -> Result<Player, String>

Sign up a new player

Adds a new player to the database.

Returns

The newly created player

pub async fn login(username: &str, password: String) -> Result<Player, String>

Login a player

Arguments
  • username - The username of the player
  • password - The password of the player
Returns

The logged in player

pub async fn logout(&self) -> Result<(), String>

Logs out a player

Arguments
  • self - The player to log out
Returns

The result of the logout operation

pub async fn change_password( &self, old_password: String, new_password: String, ) -> Result<(), String>

Change the password of a player

Arguments
  • old_password - The old password of the player
  • new_password - The new password of the player
Returns

The result of the password change

pub async fn edit( &self, bio: String, pronouns: String, alias: String, email: String, phone: String, social_media: Option<String>, accept_info_other_editions: bool, ) -> Result<(), String>

Edit player information.

Arguments
  • pronouns - The player’s pronouns.
  • alias - The player’s alias.
  • email - The player’s email.
  • phone - The player’s phone number.
  • social_media - The player’s social media links.
  • accept_info_other_editions - Whether the player accepts information about other editions.
Returns
  • Ok(()) if the player information was updated successfully.
  • Err(String) if there was an error updating the player information.
pub async fn set_pfp(&self, payload: &mut Multipart) -> Result<String, String>

Set the profile picture of a player

Arguments
  • field - The new profile picture of the player
Returns
pub async fn get_pfp(&self) -> Result<NamedFile, String>

Get the profile picture for a player

Arguments
  • self - The player
Returns

The profile picture for the player, or an error if it could not be opened

pub async fn get_player(id: String) -> Result<Option<Player>, String>

Get a player by their ID

Arguments
  • id - The ID of the player
Returns

The player with the given ID, or None if no player was found

pub async fn get_player_by_alias( alias: String, ) -> Result<Option<Player>, String>

Get a player by their alias

Arguments
  • alias - The alias of the player
Returns

The player with the given alias, or None if no player was found

pub fn get_player_alias(id: String) -> Result<String, String>

Get the alias of a player

Arguments
  • id - The ID of the player
Returns

The alias of the player, or an error if the player was not found

pub async fn get_all_players() -> Result<Vec<Player>, String>

Get all players

Returns

A vector of all players, or an error if the query failed

pub async fn get_checkpoint(&self) -> Result<(i32, i32), String>

Gets the checkpoints location

Method only available to human players.

Returns

The location of the checkpoint

pub async fn is_zombie(&self) -> bool

Check if a player is a zombie

This is checked from the PlayerState property.

Returns

True if the player is a zombie, false otherwise

pub async fn ensure_zombie(&self) -> Result<(), String>

Ensure that a player is a zombie

Acts as a guard for the zombie.rs module.

Returns

Ok if the player is a zombie, Err otherwise

Usage

This function is used to ensure that a player is a zombie before performing certain actions:

pub async fn zombie_func() {
    self.ensure_zombie().await?;
    // The rest of the function
}
pub async fn ensure_human(&self) -> Result<(), String>

Ensure that a player is a human

Acts as a guard for the human-only functions.

Returns

Ok if the player is a human, Err otherwise.

Usage

This function is used to ensure that a player is a human before performing certain actions:

pub async fn human_func() {
    self.ensure_human().await?;
    // The rest of the function
}
pub async fn is_admin(&self) -> bool

Check if the player is an admin

This is checked from the PlayerRole property.

Returns

True if the player is an admin, false otherwise

pub async fn ensure_admin(&self) -> Result<(), String>

Ensure that a player is an admin

Acts as a guard for the admin.rs module.

Returns

Ok if the player is an admin, Err otherwise

Usage

This function is used to ensure that a player is an admin before performing certain actions:

pub fn admin_func() {
    self.ensure_admin().await?;
    // The rest of the function
}
pub async fn delete_player(id: String) -> Result<usize, String>

Delete a player by ID

Arguments
  • id - The ID of the player to delete
Returns

Ok if the player was deleted, Err otherwise

Source

impl Player

pub async fn get_next_feeding(&self) -> Result<Option<CustomDateTime>, String>

Calculates the next feeding time for a zombie player.

Returns None if the player is not a zombie.

Errors

Returns an error if the player is not a zombie.

pub async fn starvation( &self, ) -> Result<Vec<(String, Option<CustomDateTime>)>, String>

Gets the starvation status of all the zombies.

Returns

A vector of tuples containing the player’s alias and their next feeding time.

Errors

Returns an error if the player is not a zombie.

pub async fn hunt( &self, target: &Player, feed1: Option<&Player>, feed2: Option<&Player>, ) -> Result<(), String>

Hunt a player and feed two other players.

Arguments
  • target - The player to hunt.
  • feed1 - The first player to feed.
  • feed2 - The second player to feed.
Errors

Returns an error if the player is not a zombie.

pub async fn zombify(&self) -> Result<(), String>

Zombify a player

Arguments
  • self - The player to zombify.
Errors

Returns an error if the player is not a zombie.

pub async fn feed( &self, amount: Option<i64>, ) -> Result<Option<CustomDateTime>, String>

Feed a player.

Arguments
  • amount - The amount of time to feed the player in hours.
Errors

Returns an error if the player is not a zombie.

pub fn feeding_time_calc() -> Result<CustomDateTime, String>

Calculates the next feeding time for a zombie.

Returns

The next feeding time as a NaiveDateTime.

pub async fn monitor_zombie_death() -> !

Monitors the zombie death and updates the player state accordingly.

Every minute, it checks if the player’s next feeding time has passed. If so, it updates the player’s state to Corpse and sets the next feeding time to None.

Errors

Returns an error if the player is not a zombie.