pub struct Player {Show 24 fields
pub id: String,
pub name: String,
pub surname: String,
pub bio: String,
pub pronouns: String,
pub alias: String,
pub niu: String,
pub email: String,
pub phone: String,
pub faculty: String,
pub isuab: bool,
pub how_did_you_hear_about_us: String,
pub social_media: Option<String>,
pub password: String,
pub player_number: i32,
pub state: PlayerState,
pub role: PlayerRole,
pub birth_date: NaiveDate,
pub accept_info_other_editions: bool,
pub next_feeding: Option<CustomDateTime>,
pub last_login: Option<NaiveDateTime>,
pub checkpoint: Option<NaiveDateTime>,
pub wants_to_be_zombie: i32,
pub register_date: Option<NaiveDateTime>,
}Expand description
Player struct
This is the main struct of the application.
It contains all the information about a player.
Fields
id: Stringname: Stringsurname: Stringbio: Stringpronouns: Stringalias: Stringniu: Stringemail: Stringphone: Stringfaculty: Stringisuab: boolhow_did_you_hear_about_us: Stringpassword: Stringplayer_number: i32state: PlayerStaterole: PlayerRolebirth_date: NaiveDateaccept_info_other_editions: boolnext_feeding: Option<CustomDateTime>last_login: Option<NaiveDateTime>checkpoint: Option<NaiveDateTime>wants_to_be_zombie: i32register_date: Option<NaiveDateTime>Implementations
Sourceimpl Player
impl Player
Sourcepub async fn recover_password(
&self,
username: String,
password: String,
) -> Result<(), String>
pub async fn recover_password( &self, username: String, password: String, ) -> Result<(), String>
Sourcepub async fn count_player(&self) -> Result<String, String>
pub async fn count_player(&self) -> Result<String, String>
Returns the number of players of each possible player state.
Returns
Ok(String)if the count was successfully retrieved.Err(String)if an error occurred.
Sourcepub async fn admin_get_players(&self) -> Result<Vec<Player>, String>
pub async fn admin_get_players(&self) -> Result<Vec<Player>, String>
Get all players for admins
Returns
Ok(Vec<Player>)if the players were successfully retrieved.Err(String)if an error occurred.
Sourcepub async fn feed_zombies_day(&self) -> Result<String, String>
pub async fn feed_zombies_day(&self) -> Result<String, String>
Adds a day to the zombies’ feeding time.
Returns
Ok(String)if the zombies were successfully fed.Err(String)if an error occurred.
Sourcepub async fn kill_all_not_at_checkpoint(&self) -> Result<String, String>
pub async fn kill_all_not_at_checkpoint(&self) -> Result<String, String>
Kills all players did not go through the checkpoint.
Returns
Ok(String)if the players were killed successfully.Err(String)if an error occurred.
Sourceimpl Player
Implement Player struct
impl Player
Implement Player struct
Sourcepub async fn new(
name: String,
surname: String,
pronouns: String,
alias: String,
niu: String,
email: String,
phone: String,
faculty: String,
isuab: bool,
how_did_you_hear_about_us: String,
social_media: Option<String>,
password: String,
birth_date: NaiveDate,
accept_info_other_editions: bool,
wants_to_be_zombie: i32,
) -> Self
pub async fn new( name: String, surname: String, pronouns: String, alias: String, niu: String, email: String, phone: String, faculty: String, isuab: bool, how_did_you_hear_about_us: String, social_media: Option<String>, password: String, birth_date: NaiveDate, accept_info_other_editions: bool, wants_to_be_zombie: i32, ) -> Self
Create a new player
Arguments
name- The player’s namesurname- The player’s surnamepronouns- The player’s pronounsalias- The player’s aliasniu- The player’s NIUemail- The player’s emailsocial_media- The player’s social mediaphone- The player’s phone numberfaculty- The player’s facultyisuab- Whether the player is from UAB or nothow_did_you_hear_about_us- How the player heard about uspassword- The player’s passwordbirth_date- The player’s birth date
Returns
A new player instance
Sourcefn get_next_player_number() -> i32
fn get_next_player_number() -> i32
Get the next player number
This is used to assign a unique number to each player.
Returns
The next player number
Sourcepub async fn change_password(
&self,
old_password: String,
new_password: String,
) -> Result<(), String>
pub async fn change_password( &self, old_password: String, new_password: String, ) -> Result<(), String>
Sourcepub async fn edit(
&self,
bio: String,
pronouns: String,
alias: String,
email: String,
phone: String,
social_media: Option<String>,
accept_info_other_editions: bool,
) -> Result<(), String>
pub async fn edit( &self, bio: String, pronouns: String, alias: String, email: String, phone: String, social_media: Option<String>, accept_info_other_editions: bool, ) -> Result<(), String>
Edit player information.
Arguments
pronouns- The player’s pronouns.alias- The player’s alias.email- The player’s email.phone- The player’s phone number.social_media- The player’s social media links.accept_info_other_editions- Whether the player accepts information about other editions.
Returns
Ok(())if the player information was updated successfully.Err(String)if there was an error updating the player information.
Sourcepub async fn get_checkpoint(&self) -> Result<(i32, i32), String>
pub async fn get_checkpoint(&self) -> Result<(i32, i32), String>
Gets the checkpoints location
Method only available to human players.
Returns
The location of the checkpoint
Sourcepub async fn is_zombie(&self) -> bool
pub async fn is_zombie(&self) -> bool
Check if a player is a zombie
This is checked from the PlayerState property.
Returns
True if the player is a zombie, false otherwise
Sourcepub async fn ensure_zombie(&self) -> Result<(), String>
pub async fn ensure_zombie(&self) -> Result<(), String>
Ensure that a player is a zombie
Acts as a guard for the zombie.rs module.
Returns
Ok if the player is a zombie, Err otherwise
Usage
This function is used to ensure that a player is a zombie before performing certain actions:
pub async fn zombie_func() {
self.ensure_zombie().await?;
// The rest of the function
}Sourcepub async fn ensure_human(&self) -> Result<(), String>
pub async fn ensure_human(&self) -> Result<(), String>
Ensure that a player is a human
Acts as a guard for the human-only functions.
Returns
Ok if the player is a human, Err otherwise.
Usage
This function is used to ensure that a player is a human before performing certain actions:
pub async fn human_func() {
self.ensure_human().await?;
// The rest of the function
}Sourcepub async fn is_admin(&self) -> bool
pub async fn is_admin(&self) -> bool
Check if the player is an admin
This is checked from the PlayerRole property.
Returns
True if the player is an admin, false otherwise
Sourcepub async fn ensure_admin(&self) -> Result<(), String>
pub async fn ensure_admin(&self) -> Result<(), String>
Ensure that a player is an admin
Acts as a guard for the admin.rs module.
Returns
Ok if the player is an admin, Err otherwise
Usage
This function is used to ensure that a player is an admin before performing certain actions:
pub fn admin_func() {
self.ensure_admin().await?;
// The rest of the function
}Sourceimpl Player
impl Player
Sourcepub async fn get_next_feeding(&self) -> Result<Option<CustomDateTime>, String>
pub async fn get_next_feeding(&self) -> Result<Option<CustomDateTime>, String>
Calculates the next feeding time for a zombie player.
Returns None if the player is not a zombie.
Errors
Returns an error if the player is not a zombie.
Sourcepub async fn starvation(
&self,
) -> Result<Vec<(String, Option<CustomDateTime>)>, String>
pub async fn starvation( &self, ) -> Result<Vec<(String, Option<CustomDateTime>)>, String>
Sourcepub async fn hunt(
&self,
target: &Player,
feed1: Option<&Player>,
feed2: Option<&Player>,
) -> Result<(), String>
pub async fn hunt( &self, target: &Player, feed1: Option<&Player>, feed2: Option<&Player>, ) -> Result<(), String>
Sourcepub fn feeding_time_calc() -> Result<CustomDateTime, String>
pub fn feeding_time_calc() -> Result<CustomDateTime, String>
Sourcepub async fn monitor_zombie_death() -> !
pub async fn monitor_zombie_death() -> !
Monitors the zombie death and updates the player state accordingly.
Every minute, it checks if the player’s next feeding time has passed. If so, it updates the player’s state to Corpse and sets the next feeding time to None.
Errors
Returns an error if the player is not a zombie.